@@ -142,7 +142,7 @@ sub cache_engine_run {
 
 	# remove fades from target track
 	
-	Audio::Nama::Effects::remove_op($args->{track}->fader) if defined $args->{track}->fader;
+	Audio::Nama::Effect::remove_op($args->{track}->fader) if defined $args->{track}->fader;
 
 	$args->{processing_time} = $setup->{audio_length} + $args->{additional_time};
 
