@@ -8,35 +8,42 @@ no warnings 'uninitialized';
 ## register data about LADSPA plugins, and Ecasound effects and
 #  presets (names, ids, parameters, hints) 
 
-sub effects_cache {
-	state $registry_format = 'json';
-	$file->effects_cache . ".$registry_format";
-}
 sub prepare_static_effects_data{
 	my $source = shift; 
 	
 	logsub("&prepare_static_effects_data");
 
-	my $effects_cache = effects_cache();
+	if (not is_test_script() ){
+		logpkg(__FILE__,__LINE__,'debug', join "\n", "newplugins:", new_plugins());
+		if (! $source and ($config->{opts}->{r} or new_plugins())){ 
 
-	logpkg(__FILE__,__LINE__,'debug', join "\n", "newplugins:", new_plugins());
-	if (! $source and ($config->{opts}->{r} or new_plugins())){ 
-
-		unlink $effects_cache;
-		print "Regenerating effects data cache\n";
+			unlink $file->effects_cache;
+			print "Regenerating effects data cache\n";
+		}
 	}
 
-	if ( ($source or -f $effects_cache) and ! $config->{opts}->{C}){  
-		logpkg(__FILE__,__LINE__,'debug', "found effects cache: $effects_cache");
-		$source //= read_file($effects_cache); # scalar assign
+	# maybe $source
+	
+	if ($config->{opts}->{T} )
+	{
+		logpkg(__FILE__,__LINE__,'debug', "using dummy effects data");
+		$source = $fx_cache->{fake};
+	}
+	elsif (-f $file->effects_cache and ! $config->{opts}->{C})
+	{  
+		logpkg(__FILE__,__LINE__,'debug', "found effects cache: ",$file->effects_cache);
+		$source = read_file($file->effects_cache); # scalar assign
+	} 
+	if ($source)
+	{
 		assign(
 			data => decode($source, 'json'),
 			vars => [qw($fx_cache)],
 			class => 'Audio::Nama'
 		);
-			
-	} else {
-		
+	}
+	else 
+	{
 		logpkg(__FILE__,__LINE__,'debug', "reading in effects data, please wait...");
 		initialize_effect_index();
 		read_in_effects_data();  
@@ -47,11 +54,13 @@ sub prepare_static_effects_data{
 		integrate_cop_hints();
 		sort_ladspa_effects();
 		prepare_effects_help();
+		logpkg(__FILE__,__LINE__,'debug', "updating effects cache on disk: ",$file->effects_cache);
 		serialize (
-			file => $effects_cache, 
+			file => $file->effects_cache, 
 			vars => [qw($fx_cache)],
 			class => 'Audio::Nama',
-			format => 'json');
+			format => 'json') unless is_test_script();
+				
 	}
 	prepare_effect_index();
 }
@@ -88,13 +97,12 @@ sub lv2_plugin_list {
 }
 
 sub new_plugins {
-	my $effects_cache = effects_cache();
 	my @filenames = ladspa_plugin_list();	
 	push @filenames, lv2_plugin_list();
 	push @filenames, '/usr/local/share/ecasound/effect_presets',
                  '/usr/share/ecasound/effect_presets',
                  "$ENV{HOME}/.ecasound/effect_presets";
-	my $effects_cache_stamp = modified_stamp($effects_cache);
+	my $effects_cache_stamp = modified_stamp($file->effects_cache);
 	my $latest;
 	map{ my $mod = modified_stamp($_);
 		 $latest = $mod if $mod > $latest } @filenames;
@@ -192,6 +200,7 @@ sub read_in_effects_data {
 	#### LADSPA
 
 	my $lr = eval_iam("ladspa-register");
+	logpkg(__FILE__,__LINE__,'debug',"ladpsa-register output:\n",$lr);
 
 	#print $lr; 
 	
@@ -199,12 +208,14 @@ sub read_in_effects_data {
 	
 	# join the two lines of each entry
 	my @lad = map { join " ", splice(@ladspa,0,2) } 1..@ladspa/2; 
+	#logpkg(__FILE__,__LINE__,'debug',join "\n","ladpsa-register processed output:",@lad);
 
 
 	#### LV2
 
 	my $lv2 = eval_iam('lv2-register'); # TODO test fake lv2-register
 										# get_data_section('fake_lv2_register');
+	logpkg(__FILE__,__LINE__,'debug',"lv2-register output:\n",$lv2);
 
 	# join wrapped lines
 	$lv2 =~ s/\n  			# newline
@@ -212,21 +223,29 @@ sub read_in_effects_data {
 						\x20		# a space
 						//gx;      # delete, multiple times, expanded regex
 
+	# join pairs of lines
+	$lv2 =~ s/\n\s*(-elv2)/ $1/g;
+
 	# now we can handle similar to LADSPA	
 	
 	# split on newlines
 	my @lv2 = split /\n/,$lv2;
 
-	logpkg(__FILE__,__LINE__,'trace',sub{ json_out(\@lv2) });
-
-	# join pairs of lines
-	@lv2 = map { join " ", splice(@lv2,0,2) } 1..@lv2/2;
+#	logpkg(__FILE__,__LINE__,'debug',sub{ json_out(\@lv2) });
 
 	logpkg(__FILE__,__LINE__,'trace',sub{ json_out(\@lv2) });
 
-	my @preset = grep {! /^\w*$/ } split "\n", eval_iam("preset-register");
-	my @ctrl  = grep {! /^\w*$/ } split "\n", eval_iam("ctrl-register");
-	my @cop = grep {! /^\w*$/ } split "\n", eval_iam("cop-register");
+	my $preset = eval_iam("preset-register");
+	my @preset = grep {! /^\s*$/ } split "\n", $preset;
+	logpkg(__FILE__,__LINE__,'debug',"preset-register output:\n",$preset);
+
+	my $ctrl = 	eval_iam("ctrl-register");
+	my @ctrl  = grep {! /^\s*$/ } split "\n", $ctrl;
+	logpkg(__FILE__,__LINE__,'debug',"ctrl-register output:\n",$ctrl);
+
+	my $cop = eval_iam("cop-register");
+	my @cop = grep {! /^\s*$/ } split "\n", $cop;
+	logpkg(__FILE__,__LINE__,'debug',"cop-register output:\n",$cop);
 
 	logpkg(__FILE__,__LINE__,'debug', "found ", scalar @cop, " Ecasound chain operators");
 	logpkg(__FILE__,__LINE__,'debug', "found ", scalar @preset, " Ecasound presets");
@@ -266,7 +285,7 @@ sub read_in_effects_data {
 		^(\d+) # number
 		\.    # dot
 		\s+   # spaces+
-		(.+?) # name
+		 (\w+) # name
 		,\s*  # comma spaces* 
 		-(pn:\w+)    # preset_id 
 		:?     # maybe colon (if parameters)
@@ -355,7 +374,7 @@ sub read_in_effects_data {
 
 sub integrate_cop_hints {
 
-	my @cop_hints =  @{ yaml_in( get_data_section('chain_op_hints_yml')) };
+	my @cop_hints =  @{ yaml_in( get_data_section('ecasound_chain_operator_hints_yml')) };
 	for my $hashref ( @cop_hints ){
 		#print "cop hints ref type is: ",ref $hashref, $/;
 		my $code = $hashref->{code};
