@@ -10,7 +10,7 @@ our @ISA;
 use vars qw($n %by_index);
 use Audio::Nama::Globals qw(:singletons %tn @fade_data); 
 use Audio::Nama::Log qw(logsub logpkg);
-use Audio::Nama::Effects qw(remove_effect add_effect effect_update_copp_set);
+use Audio::Nama::Effect  qw(remove_effect add_effect update_effect);
 # we don't import 'type' as it would clobber our $fade->type attribute
 use Audio::Nama::Object qw( 
 				 n
@@ -97,10 +97,10 @@ sub refresh_fade_controller {
 
 	# we try to re-use the controller ID
 	add_effect({
-		effect_id		=> $controller,
-		parent_id 	=> $track->fader,
+		id			=> $controller,
+		parent	 	=> $track->fader,
 		type		=> 'klg',	  		 # Ecasound controller
-		values		=> [	1,				 # Ecasound parameter 1
+		params => [	1,				 # Ecasound parameter 1
 					 		$off_level,
 					 		$on_level,
 					 		@pairs,
@@ -112,7 +112,7 @@ sub refresh_fade_controller {
 	# 	first fade is type 'out' : 100%
 	
 	 
-	effect_update_copp_set($track->fader,0, initial_level($track->name) * 100)
+	update_effect($track->fader,0, initial_level($track->name) * 100)
 }
 
 
@@ -327,7 +327,7 @@ sub add_fader {
 				before 	=> $first_effect, 
 				track	=> $track,
 				type	=> $config->{fader_op}, 
-				values	=> [0], # HARDCODED
+				params 	=> [0], # HARDCODED
 		});
 		$track->set(fader => $id);
 	}
