@@ -23,38 +23,6 @@ sub fade_around {
 	}
 	else { $coderef->(@args) }
 }
-sub fade {
-	my ($id, $param, $from, $to, $seconds) = @_;
-
-	# no fade without Timer::HiRes
-	# no fade unless engine is running
-	if ( ! engine_running() or ! $config->{hires_timer} ){
-		effect_update_copp_set ( $id, --$param, $to );
-		return;
-	}
-
-	my $steps = $seconds * $config->{fade_resolution};
-	my $wink  = 1/$config->{fade_resolution};
-	my $size = ($to - $from)/$steps;
-	logpkg(__FILE__,__LINE__,'debug', "id: $id, param: $param, from: $from, to: $to, seconds: $seconds");
-	for (1..$steps - 1){
-		modify_effect( $id, $param, '+', $size);
-		sleeper( $wink );
-	}		
-}
-
-sub fadein {
-	my ($id, $to) = @_;
-	my $from  = $config->{fade_out_level}->{fxn($id)->type};
-	fade( $id, 1, $from, $to, $config->{engine_fade_length_on_start_stop});
-}
-sub fadeout {
-	my $id    = shift;
-	my $from  =	fxn($id)->params->[0];
-	my $to	  = $config->{fade_out_level}->{fxn($id)->type};
-	fade( $id, 1, $from, $to, $config->{engine_fade_length_on_start_stop} );
-}
-
 sub solo {
 	my @args = @_;
 
@@ -78,11 +46,11 @@ sub solo {
 	
 	# get dependent tracks
 	
-	my @d = map{ $tn{$_}->bus_tree() } @names;
+	my @dependents = map{ $tn{$_}->bus_tree() } @names;
 
 	# store solo tracks and dependent tracks that we won't mute
 
-	map{ $not_mute{$_}++ } @names, @d;
+	map{ $not_mute{$_}++ } @names, @dependents;
 
 	# find all siblings tracks not in depends list
 
