@@ -5,22 +5,9 @@ package Audio::Nama;
 package Audio::Nama::Track;
 use Audio::Nama::Globals qw(:all);
 use Audio::Nama::Log qw(logpkg logsub);
+use Audio::Nama::Effect  qw(fxn);
 use List::MoreUtils qw(first_index);
-# Objects belonging to Track and its subclasses
-# have a 'class' field that is set when the 
-# object is created, and used when restoring
-# the object from a serialized state.
-
-# the ->set_track_class() method re-blesses
-# the object to a different subclass when necessary
-# changing the 'class' field as well as the object
-# class affiliation
-#
-# the ->as_hash() method (in Object.p) 
-# used to serialize will
-# sync the class field to the current object 
-# class, hopefully saving a painful error
-
+use Try::Tiny;
 use Modern::Perl;
 use Carp qw(carp cluck croak);
 use File::Copy qw(copy);
@@ -30,6 +17,7 @@ no warnings qw(uninitialized redefine);
 our $VERSION = 1.0;
 
 use Audio::Nama::Util qw(freq input_node dest_type dest_string join_path);
+use Audio::Nama::Assign qw(json_out);
 use vars qw($n %by_name @by_index %track_names %by_index);
 our @ISA = 'Audio::Nama::Wav';
 use Audio::Nama::Object qw(
@@ -38,71 +26,33 @@ use Audio::Nama::Object qw(
 					n   			
 					name
 					group 			
-
 					rw				
 					version         
 					width			
-
 					ops 			
 					vol				
 					pan				
 					fader			
 					latency_op		
 					offset			
-									
-									
-
 					old_vol_level	
 					old_pan_level
-
 					playat			
 					region_start	
 					region_end
 					modifiers		
 					looping			
-
 					hide			
-
 					source_id		
 					source_type		
-
-					
-					
-					
-					
-					
-					
-					
-					
-					
-					
-					
-					
-					
-					
-					
-					
-					
-
 					send_id			
 					send_type
-
 					target			
 					project			
-					
 					comment			
 					version_comment 
-
 					forbid_user_ops	
 					engine_group
-
-					
-					
-				    
-					
-					
-					
-					
 					current_edit    
 
 );
@@ -143,6 +93,10 @@ sub new {
 
 	my $class = shift;
 	my %vals = @_;
+	my $novol = delete $vals{novol};
+	my $nopan = delete $vals{nopan};
+	my $restore = delete $vals{restore};
+	say "restoring track $vals{name}" if $restore;
 	my @undeclared = grep{ ! $_is_field{$_} } keys %vals;
     croak "undeclared field: @undeclared" if @undeclared;
 	
@@ -177,11 +131,12 @@ sub new {
 	$track_names{$vals{name}}++;
 	$by_index{$n} = $object;
 	$by_name{ $object->name } = $object;
-	Audio::Nama::add_pan_control($n);
-	Audio::Nama::add_volume_control($n);
+	Audio::Nama::add_pan_control($n) unless $nopan or $restore;
+	Audio::Nama::add_volume_control($n) unless $novol or $restore;
 
 	$Audio::Nama::this_track = $object;
 	$Audio::Nama::ui->track_gui($object->n) unless $object->hide;
+	logpkg(__FILE__,__LINE__,'debug',$object->name, ": ","newly created track",$/,json_out($object->as_hash));
 	$object;
 }
 
@@ -759,50 +714,42 @@ sub wav_format{
 
 	
 sub mute {
-	package Audio::Nama;
+	
 	my $track = shift;
 	my $nofade = shift;
-	# do nothing if already muted
+
+	# do nothing if track is already muted
 	return if defined $track->old_vol_level();
-	if ( $fx->{params}->{$track->vol}[0] != $track->mute_level
-		and $fx->{params}->{$track->vol}[0] != $track->fade_out_level){   
-		$track->set(old_vol_level => $fx->{params}->{$track->vol}[0]);
-		fadeout( $track->vol ) unless $nofade;
-	}
-	$track->set_vol($track->mute_level);
+
+	# do nothing if track has no volume operator
+	my $vol = $track->vol_o;
+	return unless $vol;
+
+	# store vol level for unmute
+	$track->set(old_vol_level => $vol->params->[0]);
+	
+	$nofade 
+		? $vol->_modify_effect(1, $track->mute_level)
+		: $vol->fadeout
 }
 sub unmute {
-	package Audio::Nama;
 	my $track = shift;
 	my $nofade = shift;
+
 	# do nothing if we are not muted
 	return if ! defined $track->old_vol_level;
-	if ( $nofade ){
-		$track->set_vol($track->old_vol_level);
-	} 
-	else { 
-		$track->set_vol($track->fade_out_level);
-		fadein($track->vol, $track->old_vol_level);
-	}
+
+	$nofade
+		? $track->vol_o->_modify_effect(1, $track->old_vol_level)
+		: $track->vol_o->fadein($track->old_vol_level);
+
 	$track->set(old_vol_level => undef);
 }
-
-sub mute_level {
+sub apply_ops {
 	my $track = shift;
-	$config->{mute_level}->{$track->vol_type}
-}
-sub fade_out_level {
-	my $track = shift;
-	$config->{fade_out_level}->{$track->vol_type}
-}
-sub set_vol {
-	my $track = shift;
-	my $val = shift;
-	Audio::Nama::effect_update_copp_set($track->vol, 0, $val);
-}
-sub vol_type {
-	my $track = shift;
-	$fx->{applied}->{$track->vol}->{type}
+	map{ $_->apply_op }	# add operator to the ecasound chain
+	map{ fxn($_) } 		# convert to objects
+	@{ $track->ops }  	# start with track ops list
 }
 sub import_audio  { 
 	my $track = shift;
@@ -833,7 +780,7 @@ sub import_audio  {
 		my $ecs = qq(-f:$format -i:resample-hq,$frequency,"$path" -o:$destination);
 		my $path = join_path(Audio::Nama::project_dir()."convert.ecs");
 		write_file($path, $ecs);
-		load_ecs($path) or Audio::Nama::throw("$path: load failed, aborting"), return;
+		Audio::Nama::load_ecs($path) or Audio::Nama::throw("$path: load failed, aborting"), return;
 		eval_iam('start');
 		Audio::Nama::sleeper(0.2); sleep 1 while Audio::Nama::engine_running();
 	} 
@@ -860,6 +807,7 @@ sub version_has_edits {
      		and $_->host_version == $track->monitor_version
 		} values %Audio::Nama::Edit::by_name;
 }	
+# current operator and current parameter for the track
 sub op { $project->{current_op}->{$_[0]->name} //= $_[0]->{ops}->[-1] }
 
 sub param { $project->{current_param}->{$_[0]->op} //= 1 }
@@ -1018,7 +966,7 @@ sub bus { $bn{$_[0]->group} }
 sub effect_id_by_name {
 	my $track = shift;
 	my $ident = shift;
-	for my $FX (map{Audio::Nama::fxn($_)}@{$track->ops})
+	for my $FX ($track->fancy_ops_o)
 	{ return $FX->id if $FX->name eq $ident }
 }
 sub effect_nickname_count {
@@ -1029,17 +977,21 @@ sub effect_nickname_count {
 }
 sub unique_surname {
 	my ($track, $surname) = @_;
-	my $i = 0;
-	my @found;
+	# increment supplied surname to be unique to the track if necessary 
+	# return arguments:
+	# $surname, $previous_surnames
+	my $max = undef;
+	my %found;
 	for my $FX ($track->fancy_ops_o)
 	{ 
 		if( $FX->surname =~ /^$surname(\d*)$/)
 		{
-			push @found, $FX->surname; 
-			$i = $1 if $1 and $1 > $i
+			$found{$FX->surname}++;
+			no warnings qw(uninitialized numeric);
+			$max = $1 if $1 > $max;
 		}
 	}
-	$surname. (@found ? ++$i : ""), join ' ',@found
+	if (%found){ $surname.++$max, join ' ',sort keys %found } else { $surname }
 }
 sub unique_nickname {
 	my ($track, $nickname) = @_;
@@ -1055,6 +1007,7 @@ sub unique_nickname {
 	}
 	$nickname. (@found ? ++$i : ""), "@found"
 }
+# return effect IDs matching a surname
 sub with_surname {
 	my ($track, $surname) = @_;
 	my @found;
@@ -1062,7 +1015,12 @@ sub with_surname {
 	{ push @found, $FX->id if $FX->surname eq $surname }
 	@found ? "@found" : undef
 }
-{ my %system_track = map{ $_, 1} qw( Master Mixdown Eq Low Mid High Boost );
+sub vol_level { my $self = shift; try { $self->vol_o->params->[0] } }
+sub pan_level { my $self = shift; try { $self->pan_o->params->[0] } }
+sub vol_o { my $self = shift; fxn($self->vol) }
+sub pan_o { my $self = shift; fxn($self->pan) }
+{ my %system_track = map{ $_, 1} qw( Master Mixdown Eq Low
+Mid High Boost );
 sub is_user_track { ! $system_track{$_[0]->name} }
 sub is_system_track { $system_track{$_[0]->name} } 
 }
@@ -1084,7 +1042,8 @@ sub rec_status {
 }
 sub destination {
 	my $track = shift; 
-	$track->SUPER() if $track->rec_status ne OFF
+	return 'Mixdown' if $tn{Mixdown}->rec_status eq 'REC';
+	return $track->SUPER() if $track->rec_status ne OFF
 }
 #sub rec_status_display { $_[0]->rw ne OFF ? 'PLAY' : 'OFF' }
 sub busify {}
@@ -1449,11 +1408,11 @@ sub add_volume_control {
 	my $n = shift;
 	return unless need_vol_pan($ti{$n}->name, "vol");
 	
-	my $vol_id = effect_init({
+	my $vol_id = Audio::Nama::Effect->new(
 				chain => $n, 
 				type => $config->{volume_control_operator},
-				effect_id => $ti{$n}->vol, # often undefined
-				});
+				id => $ti{$n}->vol, # often undefined
+				)->id;
 	
 	$ti{$n}->set(vol => $vol_id);  # save the id for next time
 	$vol_id;
@@ -1462,11 +1421,11 @@ sub add_pan_control {
 	my $n = shift;
 	return unless need_vol_pan($ti{$n}->name, "pan");
 
-	my $pan_id = effect_init({
+	my $pan_id = Audio::Nama::Effect->new(
 				chain => $n, 
 				type => 'epp',
-				effect_id => $ti{$n}->pan, # often undefined
-				});
+				id => $ti{$n}->pan, # often undefined
+				)->id;
 	
 	$ti{$n}->set(pan => $pan_id);  # save the id for next time
 	$pan_id;
